# # #
# /26/catch_nil.rb
# (c) 2010 Jan Lelis <mail@janlelis.de>. MIT License.
# See: https://rbjl.janlelis.com/26-the-28-bytes-of-ruby-joy
# # #

# Egocentric nil
# code by Yohan, slightly edited and comments by me

# start ego mode block, usage:
# catch_nil do
#   if @some_hash[:some_key].to_formatted_array[3]
#     # do something
#   end
# end
def catch_nil(&block)
  # grip methods
  ori_method_missing   = NilClass.instance_method(:method_missing)
  catch_method_missing = NilClass.instance_method(:catch_method_missing)
  # activate ego mode
  NilClass.send :define_method, :method_missing, catch_method_missing
  # run code
  yield
ensure
  # no matter what happens: restore default nil behaviour
  NilClass.send :define_method, :method_missing, ori_method_missing
end
#alias :egonil :catch_nil # ;)

# this is the ego nil
class NilClass
  def catch_method_missing(m, *args, &block)
    nil
  end
end
